@@ -146,50 +146,7 @@
     </message>
 </context>
 <context>
-    <name>QLabel</name>
-    <message>
-        <source>Hunt and Kill</source>
-        <translation>Jage und Töte</translation>
-    </message>
-    <message>
-        <source>Kruskal</source>
-        <translation>Kruskal</translation>
-    </message>
-    <message>
-        <source>Prim</source>
-        <translation>Prim</translation>
-    </message>
-    <message>
-        <source>Recursive Backtracker</source>
-        <translation>Recursive Backtracker</translation>
-    </message>
-    <message>
-        <source>Stack</source>
-        <translation>Stapel</translation>
-    </message>
-    <message>
-        <source>Stack 2</source>
-        <translation>Stapel 2</translation>
-    </message>
-    <message>
-        <source>Stack 3</source>
-        <translation>Stapel 3</translation>
-    </message>
-    <message>
-        <source>Stack 4</source>
-        <translation>Stapel 4</translation>
-    </message>
-    <message>
-        <source>Stack 5</source>
-        <translation>Stapel 5</translation>
-    </message>
-</context>
-<context>
-    <name>Scores</name>
-    <message>
-        <source>CuteMaze Scores</source>
-        <translation>CuteMaze Punkte</translation>
-    </message>
+    <name>ScoresDialog</name>
     <message>
         <source>Name</source>
         <translation>Name</translation>
@@ -219,10 +176,28 @@
         <translation>Gratulation!</translation>
     </message>
     <message>
-        <source>Your score has made the top ten.
-Please enter your name:</source>
-        <translation>Du hast es in die Top 10 geschafft.
-Bitte trage deinen Namen ein:</translation>
+        <source>High Scores</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>#%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -422,5 +397,9 @@ Bitte trage deinen Namen ein:</translation>
         <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
         <translation>Unter der &lt;a href=%1&gt;LGPL 3&lt;/a&gt; Lizenz genutzt</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
