@@ -146,50 +146,7 @@
     </message>
 </context>
 <context>
-    <name>QLabel</name>
-    <message>
-        <source>Hunt and Kill</source>
-        <translation>Vînează şi omoară</translation>
-    </message>
-    <message>
-        <source>Kruskal</source>
-        <translation>Kruskal</translation>
-    </message>
-    <message>
-        <source>Prim</source>
-        <translation>Prim</translation>
-    </message>
-    <message>
-        <source>Recursive Backtracker</source>
-        <translation>Backtracker recursiv</translation>
-    </message>
-    <message>
-        <source>Stack</source>
-        <translation>Stivă</translation>
-    </message>
-    <message>
-        <source>Stack 2</source>
-        <translation>Stivă 2</translation>
-    </message>
-    <message>
-        <source>Stack 3</source>
-        <translation>Stivă 3</translation>
-    </message>
-    <message>
-        <source>Stack 4</source>
-        <translation>Stivă 4</translation>
-    </message>
-    <message>
-        <source>Stack 5</source>
-        <translation>Stivă 5</translation>
-    </message>
-</context>
-<context>
-    <name>Scores</name>
-    <message>
-        <source>CuteMaze Scores</source>
-        <translation>Scoruri CuteMaze</translation>
-    </message>
+    <name>ScoresDialog</name>
     <message>
         <source>Name</source>
         <translation>Nume</translation>
@@ -216,13 +173,31 @@
     </message>
     <message>
         <source>Congratulations!</source>
-        <translation>Felicitări!</translation>
+        <translation>Felicitări</translation>
     </message>
     <message>
-        <source>Your score has made the top ten.
-Please enter your name:</source>
-        <translation>Scorul dvs. a intrat în top 10.
-Vă rugăm tastaţi numele dvs.:</translation>
+        <source>High Scores</source>
+        <translation>Cele mai mari scoruri</translation>
+    </message>
+    <message>
+        <source>Rank</source>
+        <translation>Rang</translation>
+    </message>
+    <message>
+        <source>#%1</source>
+        <translation>#%1</translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation>Ţi-ai învins cel mai bun scor!</translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation>Bravo!</translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation>Ai un nou scor mare!</translation>
     </message>
 </context>
 <context>
@@ -422,5 +397,9 @@ Vă rugăm tastaţi numele dvs.:</translation>
         <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
         <translation>Folosit sub licenţă &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation>Ctrl+H</translation>
+    </message>
 </context>
 </TS>
